@@ -6,6 +6,7 @@ use warnings;
 use parent qw(Exporter);
 our @EXPORT_OK = qw(
     literal_to_value import_from
+    is_int
     p
     $STRING $NUMBER $DEBUG
 );
@@ -31,6 +32,12 @@ our $NUMBER  = qr/ [+-]? (?:
 our $DEBUG;
 $DEBUG //= $ENV{XSLATE} // '';
 
+sub is_int {
+    my($s) = @_;
+    no warnings;
+    return $s eq int($s);
+}
+
 my %esc2char = (
     't' => "\t",
     'n' => "\n",
@@ -81,23 +88,10 @@ T
     };
     Carp::confess("Xslate: Failed to import:\n" . $code . $e) if $e;
 
-    require Any::Moose;
-    if (! __PACKAGE__->can('_get_code_ref')) {
-        *_get_code_ref = Any::Moose::moose_is_preferred() ?
-            sub {
-                my($package, $name) = @_;
-                no strict 'refs';
-                no warnings 'once';
-                use warnings FATAL => 'uninitialized';
-                return *{$package . '::' . $name}{CODE};
-            } :
-            *Mouse::Util::get_code_ref
-        ;
-    }
-
     my @funcs = map {
-            my $c = _get_code_ref('Text::Xslate::Util::_import', $_);
-            $c ? ($_ => $c) : ();
+            my $glob_ref = \$Text::Xslate::Util::_import::{$_};
+            my $c = ref($glob_ref) eq 'GLOB' ? *{$glob_ref}{CODE} : undef;
+            defined($c) ? ($_ => $c) : ();
         } keys %Text::Xslate::Util::_import::;
 
     delete $Text::Xslate::Util::{'_import::'};
